From 8a71a6be34334983c23ba5edf80ac611497311e7 Mon Sep 17 00:00:00 2001
From: Nicolas Boulenguez <nicolas@debian.org>
Date: Wed, 10 Jan 2024 20:10:10 +0100
Subject: [PATCH 7/8] scripts/buildapi.mk: reduce the number of subprocesses

Ensure that dpkg-buildapi is only called at most once.

If so, call it once and cache the result for future expansions.
---
 scripts/mk/buildapi.mk | 8 +++++++-
 1 file changed, 7 insertions(+), 1 deletion(-)

diff --git a/scripts/mk/buildapi.mk b/scripts/mk/buildapi.mk
index ba6b43543..1462866c7 100644
--- a/scripts/mk/buildapi.mk
+++ b/scripts/mk/buildapi.mk
@@ -4,7 +4,13 @@ ifndef dpkg_buildapi.mk_included
 dpkg_buildapi.mk_included :=
 
 # Default API level when not set.
-DPKG_BUILD_API ?= $(shell dpkg-buildapi)
+ifndef DPKG_BUILD_API
+  # Run dpkg-buildapi if the variable is actually expanded,
+  # but then replace the recursive definition with a non-recursive one
+  # (and of course return the asked value).
+  DPKG_BUILD_API = \
+    $$(eval DPKG_BUILD_API := $$(shell dpkg-buildapi))$$(DPKG_BUILD_API)
+endif
 
 # We could use only built-in GNU make functions, but that seems too much
 # complexity given no integer operators, given that we currently have to
-- 
2.39.2

